# Autogenerated by nbdev

d = { 'settings': { 'branch': 'main',
                'doc_baseurl': '/pttn',
                'doc_host': 'https://dsm-72.github.io',
                'git_url': 'https://github.com/dsm-72/pttn',
                'lib_path': 'pttn'},
  'syms': { 'pttn.util': { 'pttn.util.attropts': ('util.html#attropts', 'pttn/util.py'),
                           'pttn.util.attrpttn': ('util.html#attrpttn', 'pttn/util.py'),
                           'pttn.util.getgroup': ('util.html#getgroup', 'pttn/util.py'),
                           'pttn.util.getpttn': ('util.html#getpttn', 'pttn/util.py'),
                           'pttn.util.ispipedopts': ('util.html#ispipedopts', 'pttn/util.py'),
                           'pttn.util.regexopts': ('util.html#regexopts', 'pttn/util.py')}}}
