__version__ = "0.0.1"
# AUTOGENERATED! DO NOT EDIT! File to edit: ../nbs/00__init__.ipynb.

# %% auto 0
__all__ = ['lib', 'mods']

# %% ../nbs/00__init__.ipynb 3
from mstar import getalls, frommods, fromstars

lib, mods = 'pttn', ('util', )
frommods(lib, *mods, scope=globals())
fromstars(lib, *mods, scope=globals())

__all__ = getalls(*tuple(globals().get(mod) for mod in mods))
